==> af-common-jpa-1.1.18.15-sources.jar: com/af/v4/system/common/jpa/dynamic/DynamicSessionFactoryImpl.java <==
package com.af.v4.system.common.jpa.dynamic;

import com.af.v4.system.common.datasource.DynamicDataSource;
import org.hibernate.*;
import org.hibernate.boot.Metadata;
import org.hibernate.boot.MetadataSources;
import org.hibernate.boot.spi.SessionFactoryOptions;
import org.hibernate.cfg.Configuration;
import org.hibernate.engine.spi.FilterDefinition;
import org.hibernate.metadata.ClassMetadata;
import org.hibernate.metadata.CollectionMetadata;
import org.hibernate.stat.Statistics;
import org.springframework.orm.hibernate5.LocalSessionFactoryBean;

import javax.naming.NamingException;
import javax.naming.Reference;
import javax.persistence.EntityGraph;
import javax.persistence.EntityManager;
import javax.persistence.PersistenceUnitUtil;
import javax.persistence.SynchronizationType;
import javax.persistence.criteria.CriteriaBuilder;
import java.io.Serial;
import java.sql.Connection;
import java.util.List;
import java.util.Map;
import java.util.Set;

/**
 * 动态数据源Session工厂实现类
 */
public class DynamicSessionFactoryImpl implements DynamicSessionFactory {

    @Serial
    private static final long serialVersionUID = 5384069312247414885L;

    private final Map<Object, LocalSessionFactoryBean> targetLocalSessionFactoryBeans;
    private final LocalSessionFactoryBean defaultLocalSessionFactoryBean;

    public DynamicSessionFactoryImpl(Map<Object, LocalSessionFactoryBean> targetLocalSessionFactoryBeans, LocalSessionFactoryBean defaultLocalSessionFactoryBean) {
        this.targetLocalSessionFactoryBeans = targetLocalSessionFactoryBeans;
        this.defaultLocalSessionFactoryBean = defaultLocalSessionFactoryBean;
    }

    @Override
    public SessionFactory getHibernateSessionFactory() {
        return getLocalSessionFactoryBean().getObject();
    }

    @Override
    public Configuration getConfiguration() {
        return getLocalSessionFactoryBean().getConfiguration();
    }

    @Override
    public LocalSessionFactoryBean getLocalSessionFactoryBean() {
        LocalSessionFactoryBean localSessionFactoryBean = targetLocalSessionFactoryBeans.get(DynamicDataSource.getDataSource());
        if (localSessionFactoryBean != null) {
            return localSessionFactoryBean;
        } else {
            return defaultLocalSessionFactoryBean;
        }
    }

    @Override
    public Metadata getMetadata() {
        MetadataSources metadataSources = new MetadataSources(
                getConfiguration().getStandardServiceRegistryBuilder().build()
        );
        return metadataSources.buildMetadata();
    }

    @Override
    public SessionFactoryOptions getSessionFactoryOptions() {
        return getHibernateSessionFactory().getSessionFactoryOptions();
    }

    @Override
    public SessionBuilder<?> withOptions() {
        return getHibernateSessionFactory().withOptions();
    }

    @Override
    public Session openSession() throws HibernateException {
        return getHibernateSessionFactory().openSession();
    }

    @Override
    public Session getCurrentSession() throws HibernateException {
        return getHibernateSessionFactory().getCurrentSession();
    }

    @Override
    public StatelessSessionBuilder<?> withStatelessOptions() {
        return getHibernateSessionFactory().withStatelessOptions();
    }

    @Override
    public StatelessSession openStatelessSession() {
        return getHibernateSessionFactory().openStatelessSession();
    }

    @Override
    public StatelessSession openStatelessSession(Connection connection) {
        return getHibernateSessionFactory().openStatelessSession(connection);
    }

    @Override
    public Statistics getStatistics() {
        return getHibernateSessionFactory().getStatistics();
    }

    @Override
    public void close() throws HibernateException {
        getHibernateSessionFactory().close();
    }

    @Override
    public Map<String, Object> getProperties() {
        return getHibernateSessionFactory().getProperties();
    }

    @Override
    public boolean isClosed() {
        return getHibernateSessionFactory().isClosed();
    }

    @Override
    public Cache getCache() {
        return getHibernateSessionFactory().getCache();
    }

    @Override
    public PersistenceUnitUtil getPersistenceUnitUtil() {
        return getHibernateSessionFactory().getPersistenceUnitUtil();
    }

    @Override
    public void addNamedQuery(String name, javax.persistence.Query query) {
        getHibernateSessionFactory().addNamedQuery(name, query);
    }

    @Override
    public <T> T unwrap(Class<T> cls) {
        return getHibernateSessionFactory().unwrap(cls);
    }

    @Override
    public <T> void addNamedEntityGraph(String graphName, EntityGraph<T> entityGraph) {
        getHibernateSessionFactory().addNamedEntityGraph(graphName, entityGraph);
    }

    @Override
    public Set<?> getDefinedFilterNames() {
        return getHibernateSessionFactory().getDefinedFilterNames();
    }

    @Override
    public FilterDefinition getFilterDefinition(String filterName) throws HibernateException {
        return getHibernateSessionFactory().getFilterDefinition(filterName);
    }

    @Override
    public boolean containsFetchProfileDefinition(String name) {
        return getHibernateSessionFactory().containsFetchProfileDefinition(name);
    }

    @Override
    public TypeHelper getTypeHelper() {
        return getHibernateSessionFactory().getTypeHelper();
    }

    @Override
    public ClassMetadata getClassMetadata(Class entityClass) {
        return getHibernateSessionFactory().getClassMetadata(entityClass);
    }

    @Override
    public ClassMetadata getClassMetadata(String entityName) {
        return getHibernateSessionFactory().getClassMetadata(entityName);
    }

    @Override
    public CollectionMetadata getCollectionMetadata(String roleName) {
        return getHibernateSessionFactory().getCollectionMetadata(roleName);
    }

    @Override
    public Map<String, ClassMetadata> getAllClassMetadata() {
        return getHibernateSessionFactory().getAllClassMetadata();
    }

    @Override
    public Map<?, ?> getAllCollectionMetadata() {
        return getHibernateSessionFactory().getAllCollectionMetadata();
    }

    @Override
    public Reference getReference() throws NamingException {
        return getHibernateSessionFactory().getReference();
    }

    @Override
    public <T> List<EntityGraph<? super T>> findEntityGraphsByType(Class<T> entityClass) {
        return getHibernateSessionFactory().findEntityGraphsByType(entityClass);
    }

    @Override
    public EntityManager createEntityManager() {
        return getHibernateSessionFactory().createEntityManager();
    }

    @Override
    public EntityManager createEntityManager(Map map) {
        return getHibernateSessionFactory().createEntityManager(map);
    }

    @Override
    public EntityManager createEntityManager(SynchronizationType synchronizationType) {
        return getHibernateSessionFactory().createEntityManager(synchronizationType);
    }

    @Override
    public EntityManager createEntityManager(SynchronizationType synchronizationType, Map map) {
        return getHibernateSessionFactory().createEntityManager(synchronizationType, map);
    }

    @Override
    public CriteriaBuilder getCriteriaBuilder() {
        return getHibernateSessionFactory().getCriteriaBuilder();
    }

    @Override
    public Metamodel getMetamodel() {
        return getHibernateSessionFactory().getMetamodel();
    }

    @Override
    public boolean isOpen() {
        return getHibernateSessionFactory().isOpen();
    }
}

==> af-common-jpa-2.8.0-sources.jar: com/af/v4/system/common/jpa/dynamic/DynamicSessionFactoryImpl.java <==
package com.af.v4.system.common.jpa.dynamic;

import com.af.v4.system.common.datasource.DynamicDataSource;
import jakarta.persistence.EntityGraph;
import jakarta.persistence.EntityManager;
import jakarta.persistence.PersistenceUnitUtil;
import jakarta.persistence.SynchronizationType;
import jakarta.persistence.metamodel.Metamodel;
import org.hibernate.*;
import org.hibernate.boot.Metadata;
import org.hibernate.boot.MetadataSources;
import org.hibernate.boot.spi.SessionFactoryOptions;
import org.hibernate.cfg.Configuration;
import org.hibernate.engine.spi.FilterDefinition;
import org.hibernate.graph.RootGraph;
import org.hibernate.query.criteria.HibernateCriteriaBuilder;
import org.hibernate.relational.SchemaManager;
import org.hibernate.stat.Statistics;
import org.springframework.orm.hibernate5.LocalSessionFactoryBean;

import javax.naming.NamingException;
import javax.naming.Reference;
import java.io.Serial;
import java.sql.Connection;
import java.util.List;
import java.util.Map;
import java.util.Set;

/**
 * 动态数据源Session工厂实现类
 */
public class DynamicSessionFactoryImpl implements DynamicSessionFactory {

    @Serial
    private static final long serialVersionUID = 5384069312247414885L;

    private final Map<Object, LocalSessionFactoryBean> targetLocalSessionFactoryBeans;
    private final LocalSessionFactoryBean defaultLocalSessionFactoryBean;

    public DynamicSessionFactoryImpl(Map<Object, LocalSessionFactoryBean> targetLocalSessionFactoryBeans, LocalSessionFactoryBean defaultLocalSessionFactoryBean) {
        this.targetLocalSessionFactoryBeans = targetLocalSessionFactoryBeans;
        this.defaultLocalSessionFactoryBean = defaultLocalSessionFactoryBean;
    }

    @Override
    public SessionFactory getHibernateSessionFactory() {
        return getLocalSessionFactoryBean().getObject();
    }

    @Override
    public Configuration getConfiguration() {
        return getLocalSessionFactoryBean().getConfiguration();
    }

    @Override
    public LocalSessionFactoryBean getLocalSessionFactoryBean() {
        LocalSessionFactoryBean localSessionFactoryBean = targetLocalSessionFactoryBeans.get(DynamicDataSource.getDataSource());
        if (localSessionFactoryBean != null) {
            return localSessionFactoryBean;
        } else {
            return defaultLocalSessionFactoryBean;
        }
    }

    @Override
    public Metadata getMetadata() {
        MetadataSources metadataSources = new MetadataSources(
                getConfiguration().getStandardServiceRegistryBuilder().build()
        );
        return metadataSources.buildMetadata();
    }

    @Override
    public SessionFactoryOptions getSessionFactoryOptions() {
        return getHibernateSessionFactory().getSessionFactoryOptions();
    }

    @Override
    public SessionBuilder withOptions() {
        return getHibernateSessionFactory().withOptions();
    }

    @Override
    public Session openSession() throws HibernateException {
        return getHibernateSessionFactory().openSession();
    }

    @Override
    public Session getCurrentSession() throws HibernateException {
        return getHibernateSessionFactory().getCurrentSession();
    }

    @Override
    public StatelessSessionBuilder withStatelessOptions() {
        return getHibernateSessionFactory().withStatelessOptions();
    }

    @Override
    public StatelessSession openStatelessSession() {
        return getHibernateSessionFactory().openStatelessSession();
    }

    @Override
    public StatelessSession openStatelessSession(Connection connection) {
        return getHibernateSessionFactory().openStatelessSession(connection);
    }

    @Override
    public Statistics getStatistics() {
        return getHibernateSessionFactory().getStatistics();
    }

    @Override
    public SchemaManager getSchemaManager() {
        return getHibernateSessionFactory().getSchemaManager();
    }

    @Override
    public void close() throws HibernateException {
        getHibernateSessionFactory().close();
    }

    @Override
    public Map<String, Object> getProperties() {
        return getHibernateSessionFactory().getProperties();
    }

    @Override
    public boolean isClosed() {
        return getHibernateSessionFactory().isClosed();
    }

    @Override
    public Cache getCache() {
        return getHibernateSessionFactory().getCache();
    }

    @Override
    public PersistenceUnitUtil getPersistenceUnitUtil() {
        return getHibernateSessionFactory().getPersistenceUnitUtil();
    }

    @Override
    public void addNamedQuery(String name, jakarta.persistence.Query query) {
        getHibernateSessionFactory().addNamedQuery(name, query);
    }

    @Override
    public <T> T unwrap(Class<T> cls) {
        return getHibernateSessionFactory().unwrap(cls);
    }

    @Override
    public <T> void addNamedEntityGraph(String graphName, EntityGraph<T> entityGraph) {
        getHibernateSessionFactory().addNamedEntityGraph(graphName, entityGraph);
    }

    @Override
    public Set<String> getDefinedFilterNames() {
        return getHibernateSessionFactory().getDefinedFilterNames();
    }

    @Override
    public FilterDefinition getFilterDefinition(String filterName) throws HibernateException {
        return getHibernateSessionFactory().getFilterDefinition(filterName);
    }

    @Override
    public Set<String> getDefinedFetchProfileNames() {
        return getHibernateSessionFactory().getDefinedFetchProfileNames();
    }

    @Override
    public boolean containsFetchProfileDefinition(String name) {
        return getHibernateSessionFactory().containsFetchProfileDefinition(name);
    }

    @Override
    public Reference getReference() throws NamingException {
        return getHibernateSessionFactory().getReference();
    }

    @Override
    public <T> List<EntityGraph<? super T>> findEntityGraphsByType(Class<T> entityClass) {
        return getHibernateSessionFactory().findEntityGraphsByType(entityClass);
    }

    @Override
    public RootGraph<?> findEntityGraphByName(String name) {
        return getHibernateSessionFactory().findEntityGraphByName(name);
    }

    @Override
    public EntityManager createEntityManager() {
        return getHibernateSessionFactory().createEntityManager();
    }

    @Override
    public EntityManager createEntityManager(Map map) {
        return getHibernateSessionFactory().createEntityManager(map);
    }

    @Override
    public EntityManager createEntityManager(SynchronizationType synchronizationType) {
        return getHibernateSessionFactory().createEntityManager(synchronizationType);
    }

    @Override
    public EntityManager createEntityManager(SynchronizationType synchronizationType, Map map) {
        return getHibernateSessionFactory().createEntityManager(synchronizationType, map);
    }

    @Override
    public HibernateCriteriaBuilder getCriteriaBuilder() {
        return getHibernateSessionFactory().getCriteriaBuilder();
    }

    @Override
    public Metamodel getMetamodel() {
        return getHibernateSessionFactory().getMetamodel();
    }

    @Override
    public boolean isOpen() {
        return getHibernateSessionFactory().isOpen();
    }
}
